{{ ansible_managed | comment }}
# Environment variables for the primary pmlogger daemon.  See also
# the pmlogger control file and pmlogconf(1) for additional details.

# Behaviour regarding listening on external-facing interfaces;
# unset PMLOGGER_LOCAL to allow connections from remote hosts.
# A value of 0 permits remote connections, 1 permits local only.
PMLOGGER_LOCAL={{ pcp_pmlogger_localonly }}

# Max length to which the queue of pending connections may grow
# A value of 5 is the default.
# PMLOGGER_MAXPENDING=5

# Default sampling interval pmlogger uses when no more specific
# interval is requested.  A value of 60 seconds is the default.
# Both pmlogger command line (via control file) and also pmlogger
# configuration file directives will override this value.
PMLOGGER_INTERVAL={{ pcp_pmlogger_interval }}

# The default behaviour, when pmlogger configuration comes from
# pmlogconf(1), is to regenerate the configuration file and check for
# changes whenever pmlogger is started from pmlogger_check(1).
# If the PMDA configuration is stable, this is not necessary, and
# setting PMLOGGER_CHECK_SKIP_LOGCONF to yes disables the regeneration
# and checking.
# PMLOGGER_CHECK_SKIP_LOGCONF=yes
